AuthAuditEvent class

Constructors

AuthAuditEvent({required AuthAuditOutcome outcome, required String realmUri, required String method, String? authId, String? message})

Properties

authId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
method → String
final
outcome → AuthAuditOutcome
final
realmUri → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited