AuthAuditLogger class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearSink() → void
failure({required String realmUri, required String method, String? authId, String? message}) → void
registerSink(void sink(AuthAuditEvent event)) → void
success({required String realmUri, required String method, required String authId}) → void