AuthSuccess class

Represents a successful authentication.

Constructors

AuthSuccess({required String authId, required String authRole, Map<String, Object?> details = const {}})
const

Properties

authId → String
final
authRole → String
final
details → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited