onAbort method
Best-effort cleanup hook when a handshake is abandoned before completion.
Implementation
Future<void> onAbort(AuthenticatorContext context, {String? reason}) async {}
Best-effort cleanup hook when a handshake is abandoned before completion.
Future<void> onAbort(AuthenticatorContext context, {String? reason}) async {}