AuthenticatorContext class

Contextual information passed to authenticators during the handshake.

Constructors

AuthenticatorContext({required RealmSettings realm, required int sessionId, required TransportMetadata transport, Map<String, Object?> helloDetails = const {}})

Properties

hashCode int
The hash code for this object.
no setterinherited
helloDetails Map<String, Object?>
final
realm RealmSettings
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
final
transport TransportMetadata
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited