create abstract method
Builds an authenticator instance for the given realm and options.
Implementation
Future<Authenticator> create(
RealmSettings realm,
Map<String, Object?> options,
);
Builds an authenticator instance for the given realm and options.
Future<Authenticator> create(
RealmSettings realm,
Map<String, Object?> options,
);