CredentialLookupEvent class

Optional hook for delivering lookup result information to observers.

Constructors

CredentialLookupEvent({required String method, required String realmUri, required String authId, required bool hit, String? reason, String? message, List? arguments, Map<String, Object?>? argumentsKeywords})

Properties

arguments → List?
final
argumentsKeywords → Map<String, Object?>?
final
authId → String
final
hashCode → int
The hash code for this object.
no setterinherited
hit → bool
final
message → String?
final
method → String
final
realmUri → String
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited