CredentialRejection class

Details describing why a credential lookup deliberately rejected access.

Implemented types

Constructors

CredentialRejection({required String reason, String? message, List? arguments, Map<String, Object?>? argumentsKeywords})

Properties

arguments → List?
final
argumentsKeywords → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
reason → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited