CryptosignCredential class

Credential payload returned by AuthCredentialProvider.loadCryptosign.

Constructors

CryptosignCredential({required String publicKey, String? channelBinding, String? role, String? provider, Map<String, Object?>? authExtra})

Properties

authExtra Map<String, Object?>?
final
channelBinding String?
final
hashCode int
The hash code for this object.
no setterinherited
provider String?
final
publicKey String
final
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited