RemoteAuthenticateRequest class

Constructors

RemoteAuthenticateRequest({required RealmSettings realmSettings, required AuthenticatorContext context, required String authId, required AuthenticateMessage authenticate, required Map<String, Object?> options, required String transactionId})

Properties

authenticate → AuthenticateMessage
final
authId → String
final
context → AuthenticatorContext
final
hashCode → int
The hash code for this object.
no setterinherited
options → Map<String, Object?>
final
realmSettings → RealmSettings
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited