RemoteAuthenticatorFactory class

Inheritance

Constructors

RemoteAuthenticatorFactory()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
method String
Method identifier handled by this factory.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(RealmSettings realm, Map<String, Object?> options) Future<Authenticator>
Builds an authenticator instance for the given realm and options.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited