RemoteHelloResponse class
Constructors
- RemoteHelloResponse.challenge(RemoteChallenge challenge)
-
const
- RemoteHelloResponse.failure(AuthFailure failure)
-
const
- RemoteHelloResponse.success(AuthSuccess success)
-
const
Properties
- challenge → RemoteChallenge?
-
final
- failure → AuthFailure?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → RemoteHelloStatus
-
final
- success → AuthSuccess?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited