AuthCredentialProvider class abstract
Pluggable credential provider used by router authenticators.
Constructors
- AuthCredentialProvider()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadCra(
{required String realmUri, required String authId}) → Future< CraCredential?> -
loadCryptosign(
{required String realmUri, required String authId}) → Future< CryptosignCredential?> -
loadScram(
{required String realmUri, required String authId}) → Future< ScramCredential?> -
loadTicket(
{required String realmUri, required String authId}) → Future< TicketCredential?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited