AuthFailure class

Represents an authentication failure.

Constructors

AuthFailure({required String reason, String? message, Map<String, Object?> details = const {}, List? arguments, Map<String, Object?>? argumentsKeywords})
const

Properties

arguments List?
final
argumentsKeywords Map<String, Object?>?
final
details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited