AuthResult class

Outcome of authentication handling.

Constructors

AuthResult.challenge(AuthChallenge challenge)
factory
AuthResult.failure(AuthFailure failure)
factory
AuthResult.success(AuthSuccess success)
factory

Properties

challenge AuthChallenge?
final
failure AuthFailure?
final
hashCode int
The hash code for this object.
no setterinherited
isChallenge bool
no setter
isFailure bool
no setter
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AuthStatus
final
success AuthSuccess?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited