AuthenticatorFactory class abstract
Factory responsible for creating authenticators for specific methods.
- Implementers
Constructors
- AuthenticatorFactory()
-
const
Properties
Methods
-
create(
RealmSettings realm, Map< String, Object?> options) → Future<Authenticator> - Builds an authenticator instance for the given realm and options.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited