factoryFor static method
Retrieves a factory by method, or null if none registered.
Implementation
static AuthenticatorFactory? factoryFor(String method) =>
_factories[method] ?? _factories[authMethodAlias(method)];
Retrieves a factory by method, or null if none registered.
static AuthenticatorFactory? factoryFor(String method) =>
_factories[method] ?? _factories[authMethodAlias(method)];