RemoteAuthenticator class
- Inheritance
-
- Object
- Authenticator
- RemoteAuthenticator
Constructors
-
RemoteAuthenticator(RemoteAuthenticatorConfig config, List<
RemoteAuthenticatorDelegate> delegates, {required List<String> delegateIds})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAbort(
AuthenticatorContext context, {String? reason}) → Future< void> -
Best-effort cleanup hook when a handshake is abandoned before completion.
override
-
onAuthenticate(
AuthenticatorContext context, AuthenticateMessage message) → Future< AuthResult> -
Handles AUTHENTICATE response after a challenge.
override
-
onHello(
AuthenticatorContext context) → Future< AuthResult> -
Handles the HELLO frame and returns a result.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resetRateLimiter(
) → void