RemoteAuthenticatorConfig class
Constructors
-
RemoteAuthenticatorConfig({required RealmSettings realm, required Map<
String, Object?> options, required String method, required List<String> delegateIds, required int challengeTimeoutMs, required Set<String> allowedRoles, required Set<String> allowedProviders, required bool fakeChallengeOnHelloFailure, required RemoteWampDelegateConfig? rpcDelegate, required int rateLimitMaxAttempts, required int rateLimitWindowMs, required int backoffBaseMs, required double backoffFactor, required int backoffMaxMs, required Duration delegateRetryDelay}) -
RemoteAuthenticatorConfig.parse(Map<
String, Object?> options, RealmSettings realm) -
factory
Properties
-
allowedProviders
→ Set<
String> -
final
-
allowedRoles
→ Set<
String> -
final
- backoffBaseMs → int
-
final
- backoffFactor → double
-
final
- backoffMaxMs → int
-
final
- challengeTimeoutMs → int
-
final
-
delegateIds
→ List<
String> -
final
- delegateRetryDelay → Duration
-
final
- fakeChallengeOnHelloFailure → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
final
-
options
→ Map<
String, Object?> -
final
- rateLimitMaxAttempts → int
-
final
- rateLimitWindowMs → int
-
final
- realm → RealmSettings
-
final
- rpcDelegate → RemoteWampDelegateConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited