RemoteAuthenticatorDelegate class abstract
Delegate invoked for remote authentication decisions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAbort(
RemoteAbortRequest request) → Future< void> -
onAuthenticate(
RemoteAuthenticateRequest request) → Future< RemoteAuthenticateResponse> -
onHello(
RemoteHelloRequest request) → Future< RemoteHelloResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited