RemoteChallenge class

Constructors

RemoteChallenge({required Map<String, Object?> challenge, required Map<String, Object?> extra, required String authId})

Properties

authId String
final
challenge Map<String, Object?>
final
extra Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited