ScramCredential class
Credential payload returned by AuthCredentialProvider.loadScram.
Constructors
Properties
-
authExtra
→ Map<
String, Object?> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations → int?
-
final
- kdf → String?
-
final
- memory → int?
-
final
- provider → String?
-
final
- role → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salt → String?
-
final
- secret → String?
-
final
- serverKey → String?
-
final
- storedKey → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited