TransportMetadata class

Metadata describing the transport connection initiating authentication.

Constructors

TransportMetadata({required int connectionId, String? peerAddress, bool isEncrypted = false})
const

Properties

connectionId int
final
hashCode int
The hash code for this object.
no setterinherited
isEncrypted bool
final
peerAddress String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited